@@ -12,6 +12,7 @@ and then combine it with the existing IFC files or IFCOWL RDF variants to integr
 """
 #IMPORT PACKAGES
 # from ast import Raise
+from pathlib import Path
 import open3d as o3d 
 import numpy as np 
 from rdflib import Graph, URIRef
@@ -84,14 +85,14 @@ class BIMNode (GeometryNode):
     @property
     def ifcPath(self): 
         """Get the ifcPath (str) of the node."""
-        return self._ifcPath
+        return ut.parse_path(self._ifcPath)
 
     @ifcPath.setter
     def ifcPath(self,value):
         if value is None:
             return None
-        if (type(value) is str and ut.get_extension(value) =='.ifc'):
-            self._ifcPath=value
+        if (ut.get_extension(str(value)) =='.ifc'):
+            self._ifcPath=str(value)
         else:
             raise ValueError('self.ifcPath has invalid type, path or extension')
 
@@ -224,6 +225,7 @@ class BIMNode (GeometryNode):
             return True
         return False
     
+    
     def get_metadata_from_ifc_path(self) -> bool:
         """Returns the metadata from a resource. \n
 
