@@ -8,6 +8,7 @@ Be sure to check the properties defined in the above classes to initialise the N
 #IMPORT PACKAGES
 from ast import Raise
 from distutils import extension
+from pathlib import Path
 import xml.etree.ElementTree as ET
 import cv2
 import PIL
@@ -94,14 +95,14 @@ class ImageNode(Node):
     @property
     def xmlPath(self): 
         """Get the xmlPath (str) of the node."""
-        return self._xmlPath
+        return ut.parse_path(self._xmlPath)
 
     @xmlPath.setter
     def xmlPath(self,value):
         if value is None:
             return None
-        elif (type(value) == str and value.endswith('xml') ):
-            self._xmlPath=value
+        elif (str(value).endswith('xml') ):
+            self._xmlPath=str(value)
         else:
             raise ValueError('self.xmlPath has invalid type, path or extension.')    
 
@@ -109,14 +110,14 @@ class ImageNode(Node):
     @property
     def xmpPath(self): 
         """Get the xmpPath (str) of the node."""
-        return self._xmpPath
+        return ut.parse_path(self._xmpPath)
 
     @xmpPath.setter
     def xmpPath(self,value):
         if value is None:
             return None
-        elif (type(value) == str and value.endswith('xmp') ):
-            self._xmpPath=value
+        elif (str(value).endswith('xmp') ):
+            self._xmpPath=str(value)
         else:
             raise ValueError('self.xmpPath has invalid type, path or extension.')    
 
@@ -378,7 +379,7 @@ class ImageNode(Node):
             mesh= o3d.geometry.TriangleMesh.create_cone(radius=radius, height=depth, resolution=20, split=1)
             rotation=gt.get_rotation_matrix(self.cartesianTransform)
             r=R.from_matrix(rotation)
-            rz=R.from_euler('xyz' ,[180, 0, 0], degrees=True)
+            rz=R.from_euler('xyz' ,[0, 0, 0], degrees=True)
             t=gt.get_translation(self.cartesianTransform)
             mesh=mesh.translate(t)
             r=rz*r
