@@ -21,6 +21,7 @@ from typing import List
 import uuid
 import datetime
 import numpy as np
+from pathlib import Path
 
 from rdflib import Graph, URIRef, Literal
 import rdflib
@@ -103,16 +104,17 @@ class Node:
             1. folder\n
             2. self.name\n
             3. self.graphPath\n
-        """        
-        return self._path
+        """
+
+        return ut.parse_path(self._path)
     
     @path.setter
-    def path(self,path):
-        if path is None:
+    def path(self,value):
+        if value is None:
             return None
         nodeExtensions=ut.get_node_resource_extensions(str(type(self)))
-        if (type(path) is str and ut.get_extension(path) in nodeExtensions):
-            self._path=path
+        if (ut.get_extension(str(value)) in nodeExtensions):
+            self._path=str(value)
         else:
             raise ValueError('self.path has invalid type, path or extension')
 
@@ -161,15 +163,15 @@ class Node:
     @property
     def graphPath(self):
         """Get the path (str) of graph of the node, or the graphPath in which the subject is contained."""
-        return self._graphPath
+        
+        return ut.parse_path(self._graphPath)
 
     @graphPath.setter
-    def graphPath(self,graphPath):
-        if graphPath is None:
+    def graphPath(self,value):
+        if value is None:
             return None
-        elif (type(graphPath) == str and 
-              next(graphPath.endswith(extension) for extension in ut.RDF_EXTENSIONS) ):
-            self._graphPath=graphPath
+        elif (next(str(value).endswith(extension) for extension in ut.RDF_EXTENSIONS) ):
+            self._graphPath=str(value)
         else:
             raise ValueError('self.graphPath has invalid type, path or extension')    
 
@@ -233,7 +235,7 @@ class Node:
             2. self.name\n
             3. self.graphPath\n
         """        
-        return self._resource
+        return self.get_resource()
 
     @resource.setter
     def resource(self,value):
@@ -313,7 +315,7 @@ class Node:
                 path=ut.literal_to_string(object)
                 if path and self._graphPath:
                     if '..' in path:
-                        path=path.strip('..\\')
+                        path=path.strip(str('..' + os.sep))
                         folder=ut.get_folder_path(ut.get_folder_path(self._graphPath))
                     else:
                         folder=ut.get_folder_path(self._graphPath)
@@ -391,6 +393,16 @@ class Node:
             else:                     
                 self._name=ut.get_subject_name(self.subject)
         return self.name
+    
+    def get_subjectname(self) -> str:
+        """Returns the subjectname (str) of the Node.\n
+
+        Returns:
+            name (str)
+        """
+                      
+        self._name=ut.get_subject_name(self.subject)
+        return self.name
 
     def set_cartesianTransform(self,value):
         """sets the cartesianTransform for the Node type. Overwrite this function for each node type.
