@@ -7,6 +7,7 @@ Be sure to check the properties defined in those abstract classes to initialise
 
 """
 #IMPORT PACKAGES
+from pathlib import Path
 import xml.etree.ElementTree as ET
 from xmlrpc.client import Boolean 
 import open3d as o3d 
@@ -63,7 +64,7 @@ class PointCloudNode (GeometryNode):
 
         #instance variables
         self.e57Index = e57Index
-        self.e57XmlPath = e57XmlPath
+        self.e57XmlPath = ut.parse_path(e57XmlPath)
 
         super().__init__(   graph= graph,
                             graphPath= graphPath,
@@ -139,7 +140,7 @@ class PointCloudNode (GeometryNode):
             o3d.geometry.PointCloud or None
         """
         if self.resource is not None and len(self.resource.points)>4:
-            pass
+            return self._resource
         elif self.get_path():
             if self.path.endswith('pcd'):
                 resource =  o3d.io.read_point_cloud(self.path)
@@ -147,7 +148,7 @@ class PointCloudNode (GeometryNode):
                 if len(resource.points)>3:
                     self._resource  =resource
             elif self.path.endswith('e57'):
-                self._resource  =gt.e57path_to_pcd(self.path, self.get_e57Index(),percentage=percentage) 
+                self._resource = gt.e57path_to_pcd(self.path, self.get_e57Index(),percentage=percentage) 
         return self._resource  
 
     def save_resource(self, directory:str=None,extension :str = '.pcd') ->bool:
@@ -183,7 +184,8 @@ class PointCloudNode (GeometryNode):
             self.path=os.path.join(directory,self.get_name() + extension)
         else:
             if self.get_path():
-                pass
+                directory = ut.get_folder(self.path)
+                
             elif(self.graphPath): 
                 dir=ut.get_folder(self.graphPath)
                 directory=os.path.join(dir,'PCD')   
@@ -191,6 +193,9 @@ class PointCloudNode (GeometryNode):
             else:
                 directory=os.path.join(os.getcwd(),'PCD')
                 self.path=os.path.join(dir,self.get_name() + extension)
+        # create directory if not present
+        if not os.path.exists(directory):                        
+            os.mkdir(directory) 
 
         #write files
         if self.path.endswith('.e57'):
