@@ -24,7 +24,7 @@ import numpy as np
 import os
 from typing import Union
 import uuid
-
+import concurrent.futures
 
 #IMPORT MODULES
 from geomapi.nodes import *
@@ -112,7 +112,7 @@ class SessionNode(GeometryNode):
             self.resources_to_linked_nodes(linkedResources)
 
         if(getResource):
-            [node.get_resource() for node in self.linkedNodes if self.linkedNodes]
+            self.get_resource()
 
         if (getMetaData):
             self.get_metadata_from_linked_nodes()
@@ -126,7 +126,8 @@ class SessionNode(GeometryNode):
 
     @linkedNodes.setter
     def linkedNodes(self,list):
-        if not list :
+        list=ut.item_to_list(list)
+        if not list or list[0] is None:
             return []
         elif all('Node' in str(type(value)) for value in list):
             self.add_linked_nodes(list)
@@ -143,7 +144,8 @@ class SessionNode(GeometryNode):
 
     @linkedSubjects.setter
     def linkedSubjects(self,list):
-        if not list :
+        list=ut.item_to_list(list)
+        if not list or list[0] is None:
             return []
         elif all('URIRef' in str(type(value)) for value in list):
             matches=[w for w in self._linkedSubjects if w in list]
@@ -349,7 +351,7 @@ class SessionNode(GeometryNode):
         
         #validate extension
         if extension not in ut.MESH_EXTENSION:
-            raise ValueError('Invalid error')
+            raise ValueError('Invalid extension')
 
         # check if already exists
         if directory and os.path.exists(os.path.join(directory,self.get_name() + extension)):
@@ -450,24 +452,81 @@ class SessionNode(GeometryNode):
             hull, _ =pcd.compute_convex_hull()
             self.resource=hull
 
-    def get_linked_resources(self):
+    def get_linked_resources(self,percentage:float=1.0):
         """Returns the resources of the linkedNodes. \n
         If none is present, it will search for the data on drive from path, graphPath, name or subject. \n
         Otherwise, it will be reconstructed from the metadata present
 
+        Args:
+            1. self (sessionNode)
+            2. percentage(float,optional): load percentage of point cloud resources in present PointCloudNodes.
+
         Returns:
             list[resource] or None
         """
-        resources=[]
         for node in self.linkedNodes:
-            if node.get_resource() is not None:
-                resources.append(node.resource)
-        return resources
+            if 'PointCloud' in str(type(node)):
+                node.get_resource(percentage)
+            else:
+                node.get_resource()
+        return [n.resource for n in self.linkedNodes]
       
+    def get_linked_resources_multiprocessing(self,percentage:float=1.0):
+        """Returns the resources of the linkedNodes by multi-processing the imports. \n
+        If none is present, it will search for the data on drive from path, graphPath, name or subject. \n
+
+        **NOTE**: Starting parallel processing takes a bit of time. As such, this method will only outperform get_linked_resources with 10+ linkedNodes
+
+        Args:
+            1. self (sessionNode)
+            2. percentage(float,optional): load percentage of point cloud resources in present PointCloudNodes.
+
+        Returns:
+            list[resource] or None
+        """
+        [n.get_path() for n in self.linkedNodes]
+
+        with concurrent.futures.ProcessPoolExecutor() as executor:
+            # first load all data and output it as np.arrays      
+            results1=[executor.submit(gt.e57_to_arrays,e57Path=n.path,e57Index=n.e57Index,percentage=percentage,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+                        if 'PointCloud' in str(type(n)) and 
+                            n.resource is None and
+                            n.path.endswith('.e57') and 
+                            os.path.exists(n.path)]
+
+            results2=[executor.submit(gt.pcd_to_arrays,path=n.path,percentage=percentage,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+                        if 'PointCloud' in str(type(n)) and 
+                            n.resource is None and
+                            n.path.endswith('.pcd') and 
+                            os.path.exists(n.path)]
+            results3=[executor.submit(gt.mesh_to_arrays,path=n.path,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+                        if ('MeshNode' in str(type(n)) or 'BIMNode' in str(type(n))) and 
+                            n.resource is None and
+                            os.path.exists(n.path)]
+            results4=[executor.submit(gt.img_to_arrays,path=n.path,tasknr=i) for i,n in enumerate(self.linkedNodes) 
+                        if 'ImageNode' in str(type(n)) and 
+                        n.resource is None and
+                        os.path.exists(n.path)]
+
+        # next, the arrays are assigned to point clouds outside the loop.
+        # Note that these loops should be in parallel as they would otherwise obstruct one another.
+        for r1 in concurrent.futures.as_completed(results1): 
+            resource=gt.arrays_to_pcd(r1.result())
+            self.linkedNodes[r1.result()[-1]].resource=resource
+        for r2 in concurrent.futures.as_completed(results2): 
+            resource=gt.arrays_to_pcd(r2.result())
+            self.linkedNodes[r2.result()[-1]].resource=resource
+        for r3 in concurrent.futures.as_completed(results3): 
+            # print(len(r3.result()[0]))
+            resource=gt.arrays_to_mesh(r3.result())
+            self.linkedNodes[r3.result()[-1]].resource=resource
+        for r4 in concurrent.futures.as_completed(results4): 
+            self.linkedNodes[r4.result()[-1]].resource=r4.result()[0]
+        return [n.resource for n in self.linkedNodes]
+
     def get_resource(self)->o3d.geometry.TriangleMesh: 
         """Returns the convexhull of the node. \n
         If none is present, it will search for the data on drive from path, graphPath, name or subject. \n
-        Otherwise, it will be reconstructed from the metadata present
 
         Returns:
             o3d.geometry.TriangleMesh or None
@@ -571,4 +630,3 @@ def create_node(graph: Graph = None, graphPath: str =None, subject: URIRef = Non
     else:
         node=Node(graph=graph, graphPath=graphPath, resource=resource, subject=subject, **kwargs) 
     return node
-
