@@ -1,6 +1,7 @@
 import copy
 import math
 import os
+from pathlib import Path
 import shutil
 import time
 import unittest
@@ -28,7 +29,7 @@ class TestNode(unittest.TestCase):
         #execute once before all tests
         print('-----------------Setup Class----------------------')
         st = time.time()
-        cls.path=os.path.join(os.getcwd(), "test","testfiles") 
+        cls.path= Path.cwd() / "test" / "testfiles" 
 
         #ONTOLOGIES
         cls.exif = rdflib.Namespace('http://www.w3.org/2003/12/exif/ns#')
@@ -43,42 +44,42 @@ class TestNode(unittest.TestCase):
         cls.ifc=rdflib.Namespace('http://ifcowl.openbimstandards.org/IFC2X3_Final#')
         
         #IFC1 (IfcWall)
-        cls.bimGraphPath1=os.path.join(cls.path,'bimGraph1.ttl')
+        cls.bimGraphPath1=cls.path / 'bimGraph1.ttl'
         cls.bimGraph1=Graph().parse(cls.bimGraphPath1)
-        cls.ifcPath1=os.path.join(cls.path,'IFC',"Academiestraat_building_1.ifc")  
-        cls.ifc1=ifcopenshell.open(cls.ifcPath1)   
+        cls.ifcPath1=cls.path / 'IFC' / "Academiestraat_building_1.ifc"  
+        cls.ifc1=ifcopenshell.open(str(cls.ifcPath1))   
         cls.ifcElement1= cls.ifc1.by_guid('0KysUSO6T3_gOJKtAiUE7d')
-        cls.path1=os.path.join(cls.path,'BIM',"Basic_Wall_211_WA_Ff1_Glued_brickwork_sandlime_150mm_1118860_0KysUSO6T3_gOJKtAiUE7d.ply")  
+        cls.path1=cls.path / 'BIM' / "Basic_Wall_211_WA_Ff1_Glued_brickwork_sandlime_150mm_1118860_0KysUSO6T3_gOJKtAiUE7d.ply"
         cls.mesh1=gt.ifc_to_mesh(cls.ifcElement1)
         cls.subject1=next(s for s in cls.bimGraph1.subjects(RDF.type) if "file:///Basic_Wall_211_WA_Ff1_Glued_brickwork_sandlime_150mm_1118860_0KysUSO6T3_gOJKtAiUE7d" in s.toPython())
         
         #IFC2 (IfcSite)
-        cls.bimGraphPath2=os.path.join(cls.path,'bimGraph2.ttl')
+        cls.bimGraphPath2=cls.path / 'bimGraph2.ttl'
         cls.bimGraph2=Graph().parse(cls.bimGraphPath2)
-        cls.ifcPath2=os.path.join(cls.path,'IFC',"Mariakerke_AWV_Conform_3D_BT_l72.ifc")  
-        cls.ifc2=ifcopenshell.open(cls.ifcPath2)   
+        cls.ifcPath2=cls.path / 'IFC' / "Mariakerke_AWV_Conform_3D_BT_l72.ifc"
+        cls.ifc2=ifcopenshell.open(str(cls.ifcPath2))   
         cls.ifcElement2= cls.ifc2.by_guid('3dzlFaOIb0bx0z6uxD96Sz')
-        cls.path2=os.path.join(cls.path,'BIM',"BT1_Bodembedekking_WSV10_3dzlFaOIb0bx0z6uxD96Sz.ply")  
+        cls.path2=cls.path / 'BIM' / "BT1_Bodembedekking_WSV10_3dzlFaOIb0bx0z6uxD96Sz.ply"
         cls.mesh2=gt.ifc_to_mesh(cls.ifcElement2) 
         cls.subject2=next(s for s in cls.bimGraph2.subjects(RDF.type) if "file:///BT1_Bodembedekking_WSV10_3dzlFaOIb0bx0z6uxD96Sz" in s.toPython())
         
         #IFC3 (IfcSlab)
-        cls.bimGraphPath3=os.path.join(cls.path,'bimGraph3.ttl')
+        cls.bimGraphPath3= cls.path / 'bimGraph3.ttl'
         cls.bimGraph3=Graph().parse(cls.bimGraphPath3)
-        cls.ifcPath3=os.path.join(cls.path,'IFC',"Academiestraat_parking.ifc")  
-        cls.ifc3=ifcopenshell.open(cls.ifcPath3)   
+        cls.ifcPath3= cls.path / 'IFC' / "Academiestraat_parking.ifc"
+        cls.ifc3=ifcopenshell.open(str(cls.ifcPath3))   
         cls.ifcElement3= cls.ifc3.by_guid('3fuhig3Pv7AexdYIkSgcdp')
-        cls.path3=os.path.join(cls.path,'BIM',"174_SFO_Pile_type_1_CS_800kN_TS_250kN_1341745_3fuhig3Pv7AexdYIkSgcdp.ply")  
+        cls.path3= cls.path / 'BIM' / "174_SFO_Pile_type_1_CS_800kN_TS_250kN_1341745_3fuhig3Pv7AexdYIkSgcdp.ply"
         cls.mesh3=gt.ifc_to_mesh(cls.ifcElement3) 
         cls.subject3=next(s for s in cls.bimGraph3.subjects(RDF.type) if "file:///174_SFO_Pile_type_1_CS_800kN_TS_250kN_1341745_3fuhig3Pv7AexdYIkSgcdp" in s.toPython())
         
         #IFC4 (IfcDoor)
-        cls.bimGraphPath4=os.path.join(cls.path,'bimGraph4.ttl')
+        cls.bimGraphPath4= cls.path / 'bimGraph4.ttl'
         cls.bimGraph4=Graph().parse(cls.bimGraphPath4)
-        cls.ifcPath4=os.path.join(cls.path,'IFC',"B1_ALG_Model.ifc")  
-        cls.ifc4=ifcopenshell.open(cls.ifcPath4)   
+        cls.ifcPath4= cls.path / 'IFC' / "B1_ALG_Model.ifc"
+        cls.ifc4=ifcopenshell.open(str(cls.ifcPath4))   
         cls.ifcElement4= cls.ifc4.by_guid('3M6cRe8S51TfU811R8bxHi')
-        cls.path4=os.path.join(cls.path,'BIM',"2RA_doors_single_omlijsting_omlijsting_-_85_x_217_1855492_3M6cRe8S51TfU811R8bxHi.ply")  
+        cls.path4= cls.path / 'BIM' / "2RA_doors_single_omlijsting_omlijsting_-_85_x_217_1855492_3M6cRe8S51TfU811R8bxHi.ply"
         cls.mesh4=gt.ifc_to_mesh(cls.ifcElement4) 
         cls.subject4=next(s for s in cls.bimGraph4.subjects(RDF.type) if "file:///2RA_doors_single_omlijsting_omlijsting_-_85_x_217_1855492_3M6cRe8S51TfU811R8bxHi" in s.toPython())
        
@@ -230,21 +231,21 @@ class TestNode(unittest.TestCase):
         self.assertEqual(node.subject,self.subject3)
         node.to_graph()
         object=node.graph.value(node.subject,self.v4d['path'])
-        self.assertEqual(object.toPython(),os.path.join("BIM",ut.get_filename(self.path3)+'.ply') )
+        self.assertEqual(ut.parse_path(object.toPython()),(Path("BIM") / (ut.get_filename(self.path3) + '.ply')).as_posix() )
 
     def test_creation_from_subject_mesh_path_ifcPath_graph(self):      
         node= BIMNode(subject=self.subject4,resource=self.mesh4,path=self.path4, ifcPath=self.ifcPath4, graph=self.bimGraph4)
         self.assertEqual(node.subject,self.subject4 )
         node.to_graph()
         object=node.graph.value(node.subject,self.v4d['path'])
-        self.assertEqual(object.toPython(),os.path.join("BIM",ut.get_filename(self.path4)+'.ply') )
+        self.assertEqual(ut.parse_path(object.toPython()),(Path("BIM") / (ut.get_filename(self.path4) + '.ply')).as_posix() )
 
     def test_creation_from_subject_mesh_path_ifcPath_globalId_graph(self):      
         node= BIMNode(subject=self.subject1,resource=self.mesh1,path=self.path1, ifcPath=self.ifcPath1, globalId=self.ifcElement1.GlobalId, graph=self.bimGraph1)
         self.assertEqual(node.subject,self.subject1)
         node.to_graph()
         object=node.graph.value(node.subject,self.v4d['path'])
-        self.assertEqual(object.toPython(),os.path.join("BIM",ut.get_filename(self.path1)+'.ply') )
+        self.assertEqual(ut.parse_path(object.toPython()),(Path("BIM") / (ut.get_filename(self.path1) + '.ply')).as_posix() )
 
     def test_node_creation_with_get_resource(self):
         #mesh
@@ -374,21 +375,21 @@ class TestNode(unittest.TestCase):
         #valid path
         node=BIMNode()
         node.path= self.path1
-        self.assertEqual(node.path,self.path1)
+        self.assertEqual(node.path,self.path1.as_posix())
 
         #preexisting
         node=BIMNode(path=self.path4)
-        self.assertEqual(node.path,self.path4)
+        self.assertEqual(node.path,self.path4.as_posix())
 
         #graphPath & name
         node=BIMNode(subject=self.subject4,graphPath=self.bimGraphPath4)
         node.get_path()
-        self.assertEqual(node.path,self.path4)
+        self.assertEqual(node.path,self.path4.as_posix())
 
     def test_set_ifc_path(self):
         #valid path
         node=BIMNode(ifcPath=self.ifcPath2)
-        self.assertEqual(node.ifcPath,self.ifcPath2)
+        self.assertEqual(node.ifcPath,self.ifcPath2.as_posix())
 
         #invalid
         self.assertRaises(ValueError,BIMNode,ifcPath='qsffqsdf.dwg')
